Class: Fastlane::Helper::FlutterHelper

Inherits:
Object
  • Object
show all
Defined in:
lib/fastlane/plugin/flutter/helper/flutter_helper.rb

Class Method Summary collapse

Class Method Details

.dev_dependency?(package) ⇒ Boolean

Returns:

  • (Boolean)


44
45
46
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 44

def self.dev_dependency?(package)
  (YAML.load_file('pubspec.yaml')['dev_dependencies'] || {}).key?(package)
end

.execute(*command) ⇒ Object



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 72

def self.execute(*command)
  # TODO(dotdoom): make CommandExecutor (and Actions.sh) behave similarly.
  command = command.shelljoin
  UI.command(command)
  Open3.popen3(command) do |stdin, stdout, stderr, wait_thread|
    errors_thread = Thread.new { stderr.read }
    stdin.close

    if block_given?
      output = stdout.read
      ignore_error = yield(wait_thread.value, output, errors_thread)
    else
      stdout.each_line do |stdout_line|
        UI.command_output(stdout_line.chomp)
      end
    end

    unless wait_thread.value.success? || (ignore_error == true)
      UI.shell_error!("The following command has failed:\n\n$ \#{command}\n[\#{wait_thread.value}]\n\n\#{errors_thread.value}\n")
    end

    ignore_error
  end
end

.flutter(*argv, &block) ⇒ Object



7
8
9
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 7

def self.flutter(*argv, &block)
  execute(flutter_binary, *argv, &block)
end

.flutter_binaryObject



40
41
42
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 40

def self.flutter_binary
  File.join(flutter_sdk_root, 'bin', 'flutter')
end

.flutter_installed?Boolean

Returns:

  • (Boolean)


35
36
37
38
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 35

def self.flutter_installed?
  # Can't use File.executable? because on Windows it has to be .exe.
  File.exist?(flutter_binary)
end

.flutter_sdk_rootObject



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 15

def self.flutter_sdk_root
  @flutter_sdk_root ||= File.expand_path(
    if ENV.include?('FLUTTER_SDK_ROOT')
      UI.deprecated(
        'FLUTTER_SDK_ROOT environment variable is deprecated. ' \
        'To point to a Flutter installation directory, use ' \
        'FLUTTER_ROOT instead.'
      )
      ENV['FLUTTER_SDK_ROOT']
    elsif ENV.include?('FLUTTER_ROOT')
      # FLUTTER_ROOT is a standard environment variable from Flutter.
      ENV['FLUTTER_ROOT']
    elsif flutter_binary = FastlaneCore::CommandExecutor.which('flutter')
      File.dirname(File.dirname(flutter_binary))
    else
      File.join(Dir.pwd, 'vendor', 'flutter')
    end
  )
end

.git(*argv, &block) ⇒ Object



11
12
13
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 11

def self.git(*argv, &block)
  execute('git', *argv, &block)
end

.import_path_for_test(file_to_import, relative_path) ⇒ Object



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 52

def self.import_path_for_test(file_to_import, relative_path)
  unless file_to_import.start_with?('lib/')
    return File.join(relative_path, file_to_import)
  end

  # Import file schema in tests have to match files in lib/ exactly. From
  # Dart perspective, symbols in files imported via relative and
  # "package:" file paths are different symbols.
  package_specification = "package:#{pub_package_name}/"
  if File.read(file_to_import, 4096).include?(package_specification)
    # If there's a package reference in the first few bytes of the file,
    # chances are, it's using "package:..." imports. Indeed, checking the
    # file itself isn't sufficient to explore all of its dependencies, but
    # we expect imports to be consistent in the project.
    "#{package_specification}#{file_to_import['lib/'.size..-1]}"
  else
    File.join(relative_path, file_to_import)
  end
end

.pub_package_nameObject



48
49
50
# File 'lib/fastlane/plugin/flutter/helper/flutter_helper.rb', line 48

def self.pub_package_name
  YAML.load_file('pubspec.yaml')['name']
end